%define major		2
%define libname		%mklibname %{name} %{major}
%define major_itp	0
%define libname_itp	%mklibname %{name}machine %{major_itp}
%define major_http	0
%define libname_http	%mklibname httpdfaust %{major_http}
%define major_osc	1
%define libname_osc	%mklibname oscfaust %{major_osc}
%define develname	%mklibname %{name} -d

Name:		faust
Version:	2.77.3
Release:	%mkrel 1
Summary:	Functional programming language for realtime audio applications
License:	GPLv2
Group:		System/Libraries
URL:		https://faust.grame.fr/
Source0:	https://github.com/grame-cncm/faust/releases/download/%{version}/%{name}-%{version}.tar.gz
Patch0:		faust-repack.patch

BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	llvm-devel
BuildRequires:	pkgconfig(libmicrohttpd)

%description
Faust (Functional Audio Stream) is a functional programming
language for sound synthesis and audio processing with a
strong focus on the design of synthesizers, musical
instruments, audio effects, etc. created at the GRAME-CNCM
Research Department. Faust targets high-performance signal
processing applications and audio plug-ins for a variety
of platforms and standards.

The core component of Faust is its compiler. It allows to
"translate" any Faust digital signal processing (DSP)
specification to a wide range of non-domain specific
languages such as C++, C, LLVM bit code, WebAssembly,
Rust, etc. In this regard, Faust can be seen as an alternative
to C++ but is much simpler and intuitive to learn.

#------------------------------------------------

%package -n	%{libname}
Summary:	Functional programming language for realtime audio applications
Group:		System/Libraries

%description -n	%{libname}
Faust (Functional Audio Stream) is a functional programming
language for sound synthesis and audio processing with a
strong focus on the design of synthesizers, musical
instruments, audio effects, etc. created at the GRAME-CNCM
Research Department. Faust targets high-performance signal
processing applications and audio plug-ins for a variety
of platforms and standards.

The core component of Faust is its compiler. It allows to
"translate" any Faust digital signal processing (DSP)
specification to a wide range of non-domain specific
languages such as C++, C, LLVM bit code, WebAssembly,
Rust, etc. In this regard, Faust can be seen as an alternative
to C++ but is much simpler and intuitive to learn.

#------------------------------------------------

%package -n	%{libname_itp}
Summary:	Faust Machine library
Group:		System/Libraries

%description -n	%{libname_itp}
Faust Machine component library.

#------------------------------------------------

%package -n	%{libname_http}
Summary:	HTTPD Faust library
Group:		System/Libraries

%description -n	%{libname_http}
HTTPD Faust component library.

#------------------------------------------------

%package -n	%{libname_osc}
Summary:	OSC Faust library
Group:		System/Libraries

%description -n	%{libname_osc}
OSC Faust component library.

#------------------------------------------------

%package -n	%{develname}
Summary:	Development package for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Requires:	%{libname_itp} = %{version}-%{release}
Requires:	%{libname_http} = %{version}-%{release}
Requires:	%{libname_osc} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
Header files for development with %{name}.

#------------------------------------------------

%prep
%autosetup -p1

%build
pushd build
%cmake -DLIBSDIR=%{_lib} \
       -DINCLUDE_STATIC=OFF \
       -DINCLUDE_DYNAMIC=ON \
       -DINCLUDE_OSC=ON \
       -DOSCDYNAMIC=ON \
       -DINCLUDE_HTTP=ON \
       -DHTTPDYNAMIC=ON \
       -DINCLUDE_ITP=ON \
       -DITPDYNAMIC=ON
%cmake_build
popd

%install
pushd build
%cmake_install
popd

find %{buildroot}%{_libdir} -name '*.a' -delete

# remove NaziOS crap
rm -fr %{buildroot}%{_datadir}/faust/iOS/
rm -fr %{buildroot}%{_datadir}/faust/smartKeyboard/
# and the unneeded android lib too
rm -fr %{buildroot}%{_datadir}/faust/android/

%files
%doc README.md
%license COPYING.txt
%{_bindir}/faust*
%{_bindir}/encoderunitypackage
%{_bindir}/filename2ident
%{_bindir}/sound2reader
%{_bindir}/usage.sh
%{_datadir}/%{name}/
%{_mandir}/man1/%{name}.1*

%files -n %{libname}
%doc README.md
%license COPYING.txt
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{libname_itp}
%license COPYING.txt
%{_libdir}/lib%{name}machine.so.%{major_itp}{,.*}
%{_libdir}/lib%{name}machine.so.1.0.0

%files -n %{libname_http}
%license COPYING.txt
%{_libdir}/libHTTPDFaust.so.%{major_http}{,.*}

%files -n %{libname_osc}
%license COPYING.txt
%{_libdir}/libOSCFaust.so.%{major_osc}{,.*}

%files -n %{develname}
%doc README.md
%license COPYING.txt
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}machine.so
%{_libdir}/libHTTPDFaust.so
%{_libdir}/libOSCFaust.so


%changelog
* Tue Feb 04 2025 daviddavid <daviddavid> 2.77.3-1.mga10
+ Revision: 2145061
- new version: 2.77.3

* Tue Jul 23 2024 daviddavid <daviddavid> 2.74.6-1.mga10
+ Revision: 2082325
- new version: 2.74.6

* Sat May 11 2024 daviddavid <daviddavid> 2.72.14-1.mga10
+ Revision: 2063574
- new version: 2.72.14

* Tue Sep 19 2023 daviddavid <daviddavid> 2.68.1-1.mga10
+ Revision: 1987998
- new version: 2.68.1

* Sun May 21 2023 daviddavid <daviddavid> 2.59.6-1.mga9
+ Revision: 1957663
- initial package faust (needed for csound-plugins)

